Examples
=============
This is the example library of biapol-utilities. We provide examples for all top-level functions that are listed
in the API reference and comment on their usage here.

Label module
------------------
The label module bundles functions that operate on label images, i.e. images with annotated objects. The idendity of
an object is encoded in the pixel value which must be an integer number.

.. toctree::
    :titlesonly:
    :maxdepth: 0

    Match labels <notebooks/label/match_labels.ipynb>
    Compare segmentations <notebooks/label/Compare_segmentations.ipynb>
    Visualize labels <notebooks/label/visualize_labels.ipynb>

Data module
------------------
The data module provides example data to be usedin the examples section.
